referrerpolicy=no-referrer-when-downgrade

approve_attempt

Function approve_attempt 

pub fn approve_attempt<T: Config>(
    lost: AccountIdLookupOf<T>,
    friend_group_index: FriendGroupIndex,
)
Approve the recovery for a lost account.

Must be called by a friend of the friend group that the recovery attempt belongs to that did not yet vote. Voting is only allowed until the threshold is reached. finish_attempt should be called after the last friend voted.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::approve_attempt.