referrerpolicy=no-referrer-when-downgrade

cancel_attempt

Function cancel_attempt 

pub fn cancel_attempt<T: Config>(
    lost: AccountIdLookupOf<T>,
    friend_group_index: FriendGroupIndex,
)
The lost account can cancel an attempt at any moment; the initiator, only after a delay.

This will release the security deposit back to the initiator. The cancel delay must be respected if the initiator calls it to prevent it from front-running the lost account from slashing the attempt.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::cancel_attempt.