referrerpolicy=no-referrer-when-downgrade

control_inherited_account

Function control_inherited_account 

pub fn control_inherited_account<T: Config>(
    recovered: AccountIdLookupOf<T>,
    call: Box<<T as Config>::RuntimeCall>,
)
Allows the inheritor of a recovered account to control it.

The controller is not allowed to dispatch calls of the recovery pallet. Otherwise they could mess with the recovery configuration and possibly cancel or slash attempts from higher-priority friend groups.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::control_inherited_account.