referrerpolicy=no-referrer-when-downgrade

finish_attempt

Function finish_attempt 

pub fn finish_attempt<T: Config>(
    lost: AccountIdLookupOf<T>,
    friend_group_index: FriendGroupIndex,
)
Finish a recovery attempt and make the lost account accessible from the inheritor.

Can be called by anyone who is willing to pay for the inheritor deposit.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::finish_attempt.