referrerpolicy=no-referrer-when-downgrade

revoke_inheritor

Function revoke_inheritor 

pub fn revoke_inheritor<T: Config>()
Revoke the inheritor of the calling (lost) account.

This removes the inheritor entry and refunds the inheritor deposit. Can only be called by the lost account itself after it regains access.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::revoke_inheritor.