pub fn set_friend_groups<T: Config>(friend_groups: Vec<FriendGroupOf<T>>)Expand description
Set the friend groups of the calling account before it lost access.
Cannot be used while there are ongoing recovery attempts. The friends of each group MUST be sorted and unique. Trying to insert two friend groups with the same set of friends will result in an error.
A FriendGroupsChanged event is emitted only when the new friends groups differed from
the old ones.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_friend_groups.