pub fn slash_attempt<T: Config>(friend_group_index: FriendGroupIndex)Expand description
Slash a malicious recovery attempt and burn the security deposit of the initiator.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::slash_attempt.